pub struct Binding<T> {
pub mods: ModifiersState,
pub action: Action,
pub mode: BindingMode,
pub notmode: BindingMode,
pub trigger: T,
}Expand description
Describes a state and action to take in that state.
This is the shared component of MouseBinding and KeyBinding.
Fields
mods: ModifiersStateModifier keys required to activate binding.
action: ActionString to send to PTY if mods and mode match.
mode: BindingModeBinding mode required to activate binding.
notmode: BindingModeExcluded binding modes where the binding won’t be activated.
trigger: TThis property is used as part of the trigger detection code.
For example, this might be a key like “G”, or a mouse button.
Implementations
Sourceimpl<T: Eq> Binding<T>
impl<T: Eq> Binding<T>
pub fn is_triggered_by( &self, mode: BindingMode, mods: ModifiersState, input: &T, ) -> bool
pub fn triggers_match(&self, binding: &Binding<T>) -> bool