pub type KeyBinding = Binding<BindingKey>;Expand description
Bindings that are triggered by a keyboard key.
Aliased Type
struct KeyBinding {
pub mods: ModifiersState,
pub action: Action,
pub mode: BindingMode,
pub notmode: BindingMode,
pub trigger: BindingKey,
}Fields
mods: ModifiersStateModifier keys required to activate binding.
action: ActionString to send to PTY if mods and mode match.
mode: BindingModeBinding mode required to activate binding.
notmode: BindingModeExcluded binding modes where the binding won’t be activated.
trigger: BindingKeyThis property is used as part of the trigger detection code.
For example, this might be a key like “G”, or a mouse button.