pub type MouseBinding = Binding<MouseButton>;Expand description
Bindings that are triggered by a mouse button.
Aliased Type
struct MouseBinding {
pub mods: ModifiersState,
pub action: Action,
pub mode: BindingMode,
pub notmode: BindingMode,
pub trigger: MouseButton,
}Fields
mods: ModifiersStateModifier keys required to activate binding.
action: ActionString to send to PTY if mods and mode match.
mode: BindingModeBinding mode required to activate binding.
notmode: BindingModeExcluded binding modes where the binding won’t be activated.
trigger: MouseButtonThis property is used as part of the trigger detection code.
For example, this might be a key like “G”, or a mouse button.